@@ -17,8 +17,9 @@ else:
 
 SNAPSHOTTEST_INSTALLED = False
 try:
-    import snapshottest  # noqa
-except ImportError:
+    import snapshottest
+    assert snapshottest.__file__  # confirm that the snapshottest module is actually installed
+except (ImportError, AssertionError):
     pass
 else:
     SNAPSHOTTEST_INSTALLED = True
